@@ -18,7 +18,7 @@ enum GVAccess_Work {
     GVAW_dialOut,                   // Destination number, callout number
     GVAW_getRegisteredPhones,
     GVAW_getInbox,                  // type, start page, page count, last update
-    GVAW_getContactFromHistoryLink, // History link
+    GVAW_getContactFromInboxLink,   // Inbox link
     GVAW_sendSMS,                   // Number, text
     GVAW_playVmail,                 // Voicemail link
 };
@@ -59,6 +59,9 @@ protected:
     GVAccess (QObject *parent = NULL);
     virtual ~GVAccess ();
 
+    //! This function will find out the proxy information for the system
+    bool getSystemProxies (QNetworkProxy &http, QNetworkProxy &https);
+
 public:
     bool enqueueWork (GVAccess_Work whatwork, const QVariantList &params,
                       QObject      *receiver, const char         *method);
@@ -72,6 +75,12 @@ public:
 
     virtual void setView (QWidget *view);
 
+    bool setProxySettings (bool bEnable,
+                           bool bUseSystemProxy,
+                           const QString &host, int port,
+                           bool bRequiresAuth,
+                           const QString &user, const QString &pass);
+
 signals:
     //! Status emitter
     void status(const QString &strText, int timeout = 2000);
@@ -93,8 +102,8 @@ signals:
     void registeredPhone (const GVRegisteredNumber &info);
     //! Emitted when dialing has started (for callback method)
     void dialInProgress (const QString &strNumber);
-    //! Emitted for every history event
-    void oneHistoryEvent (const GVHistoryEvent &hevent);
+    //! Emitted for every inbox entry
+    void oneInboxEntry (const GVInboxEntry &hevent);
     //! Emitted when GV returns an access number to dial out
     void dialAccessNumber (const QString  &strAccessNumber,
                            const QVariant &context        );
@@ -142,10 +151,10 @@ protected:
     virtual bool dialCallback (bool bCallback) = 0;
     //! Get registered phones from the settings page
     virtual bool getRegisteredPhones () = 0;
-    //! Begin the process to get history
-    virtual bool getHistory () = 0;
-    //! Call a number given the history entry's link
-    virtual bool getContactFromHistoryLink () = 0;
+    //! Begin the process to get inbox
+    virtual bool getInbox () = 0;
+    //! Call a number given the inbox entry link
+    virtual bool getContactFromInboxLink () = 0;
     //! This sends SMSes
     virtual bool sendSMS () = 0;
     //! Play a voicemail
