@@ -1,6 +1,6 @@
 #include "GVWebPage.h"
 #include "Singletons.h"
-#include "GVH_XMLJsonHandler.h"
+#include "GVI_XMLJsonHandler.h"
 
 #define GV_DATA_BASE "https://www.google.com/voice"
 
@@ -15,10 +15,6 @@ GVWebPage::GVWebPage(QObject *parent/* = NULL*/)
 //     webPage.settings()->setAttribute (QWebSettings::AutoLoadImages, false);
     webPage.setForwardUnsupportedContent (true);
 
-    QNetworkProxy http, https;
-    getSystemProxies (http, https);
-    QNetworkProxy::setApplicationProxy (http);
-
     garbageTimer.setSingleShot (true);
     garbageTimer.setInterval (1000 * 60 * 2);   // 2 minutes
 
@@ -863,7 +859,7 @@ GVWebPage::sendInboxRequest ()
                            QVariant::fromValue(sendCookies));
 
         QObject::connect (mgr , SIGNAL (finished (QNetworkReply *)),
-                          this, SLOT   (onGotHistoryXML (QNetworkReply *)));
+                          this, SLOT   (onGotInboxXML (QNetworkReply *)));
         mgr->get (request);
     } while (0); // End cleanup block (not a loop)
 
@@ -871,7 +867,7 @@ GVWebPage::sendInboxRequest ()
 }//GVWebPage::sendInboxRequest
 
 bool
-GVWebPage::getHistory ()
+GVWebPage::getInbox ()
 {
     QMutexLocker locker(&mutex);
     if (!bLoggedIn)
@@ -883,24 +879,24 @@ GVWebPage::getHistory ()
     nFirstPage = nCurrent = workCurrent.arrParams[1].toString().toInt ();
 
     return sendInboxRequest ();
-}//GVWebPage::getHistory
+}//GVWebPage::getInbox
 
 void
-GVWebPage::onGotHistoryXML (QNetworkReply *reply)
+GVWebPage::onGotInboxXML (QNetworkReply *reply)
 {
     QNetworkAccessManager *mgr = webPage.networkAccessManager ();
     QObject::disconnect (mgr , SIGNAL (finished (QNetworkReply *)),
-                         this, SLOT   (onGotHistoryXML (QNetworkReply *)));
+                         this, SLOT   (onGotInboxXML (QNetworkReply *)));
 
     QString strReply = reply->readAll ();
     QXmlInputSource inputSource;
     QXmlSimpleReader simpleReader;
     inputSource.setData (strReply);
-    GVH_XMLJsonHandler xmlHandler;
+    GVI_XMLJsonHandler xmlHandler;
 
     QObject::connect (
-        &xmlHandler, SIGNAL (oneElement (const GVHistoryEvent &)),
-         this      , SIGNAL (oneHistoryEvent (const GVHistoryEvent &)));
+        &xmlHandler, SIGNAL (oneElement (const GVInboxEntry &)),
+         this      , SIGNAL (oneInboxEntry (const GVInboxEntry &)));
 
     bool bOk = false;
     do // Begin cleanup block (not a loop)
@@ -920,7 +916,7 @@ GVWebPage::onGotHistoryXML (QNetworkReply *reply)
         bool bGotOld = false;
         if (!xmlHandler.parseJSON (dtUpdate, bGotOld))
         {
-            qWarning ("Failed to parse GV History JSON");
+            qWarning ("Failed to parse GV Inbox JSON");
             break;
         }
 
@@ -946,16 +942,16 @@ GVWebPage::onGotHistoryXML (QNetworkReply *reply)
     }
 
     reply->deleteLater ();
-}//GVWebPage::onGotHistoryXML
+}//GVWebPage::onGotInboxXML
 
 bool
-GVWebPage::getContactFromHistoryLink ()
+GVWebPage::getContactFromInboxLink ()
 {
     QMutexLocker locker(&mutex);
     if (!bLoggedIn)
     {
-        qWarning ("User not logged in when calling history link");
-        completeCurrentWork (GVAW_getContactFromHistoryLink, false);
+        qWarning ("User not logged in when calling Inbox link");
+        completeCurrentWork (GVAW_getContactFromInboxLink, false);
         return (false);
     }
 
@@ -965,18 +961,18 @@ GVWebPage::getContactFromHistoryLink ()
                     + workCurrent.arrParams[0].toString();
     QObject::connect (
         &webPage, SIGNAL (loadFinished (bool)),
-         this   , SLOT   (getContactFromHistoryLinkLoaded (bool)));
+         this   , SLOT   (getContactFromInboxLinkLoaded (bool)));
     this->loadUrlString (strGoto);
 
     return (true);
-}//GVWebPage::getContactFromHistoryLink
+}//GVWebPage::getContactFromInboxLink
 
 void
-GVWebPage::getContactFromHistoryLinkLoaded (bool bOk)
+GVWebPage::getContactFromInboxLinkLoaded (bool bOk)
 {
     QObject::disconnect (
         &webPage, SIGNAL (loadFinished (bool)),
-         this   , SLOT   (getContactFromHistoryLinkLoaded (bool)));
+         this   , SLOT   (getContactFromInboxLinkLoaded (bool)));
 
     GVContactInfo info;
     do // Begin cleanup block (not a loop)
@@ -984,7 +980,7 @@ GVWebPage::getContactFromHistoryLinkLoaded (bool bOk)
         if (isLoadFailed (bOk))
         {
             bOk = false;
-            qWarning ("Failed to load call history link page");
+            qWarning ("Failed to load Inbox link page");
             break;
         }
         bOk = false;
@@ -1037,8 +1033,8 @@ GVWebPage::getContactFromHistoryLinkLoaded (bool bOk)
         emit contactInfo (info);
     }
 
-    completeCurrentWork (GVAW_getContactFromHistoryLink, bOk);
-}//GVWebPage::getContactFromHistoryLinkLoaded
+    completeCurrentWork (GVAW_getContactFromInboxLink, bOk);
+}//GVWebPage::getContactFromInboxLinkLoaded
 
 void
 GVWebPage::garbageTimerTimeout ()
@@ -1227,83 +1223,3 @@ GVWebPage::onVmailDownloaded (QNetworkReply *reply)
     completeCurrentWork (GVAW_playVmail, rv);
     reply->deleteLater ();
 }//GVWebPage::onVmailDownloaded
-
-bool
-GVWebPage::getSystemProxies (QNetworkProxy &http, QNetworkProxy &https)
-{
-    QNetworkProxyFactory::setUseSystemConfiguration (true);
-
-    do { // Begin cleanup block (not a loop)
-        QList<QNetworkProxy> netProxies =
-        QNetworkProxyFactory::systemProxyForQuery (
-        QNetworkProxyQuery(QUrl("http://www.google.com")));
-        http = netProxies[0];
-        if (QNetworkProxy::NoProxy != http.type ()) {
-            qDebug () << "Got proxy: host = " << http.hostName ()
-                      << ", port = " << http.port ();
-            break;
-        }
-
-        // Otherwise Confirm it
-#if defined(Q_WS_X11)
-        QString strHttpProxy = getenv ("http_proxy");
-        if (strHttpProxy.isEmpty ()) {
-            break;
-        }
-
-        int colon = strHttpProxy.lastIndexOf (':');
-        if (-1 != colon) {
-            QString strHost = strHttpProxy.mid (0, colon);
-            QString strPort = strHttpProxy.mid (colon);
-
-            strHost.remove ("http://").remove ("https://");
-
-            strPort.remove (':').remove ('/');
-            int port = strPort.toInt ();
-
-            qDebug () << "Found http proxy: " << strHost << ":" << port;
-            http.setHostName (strHost);
-            http.setPort (port);
-            http.setType (QNetworkProxy::HttpProxy);
-        }
-#endif
-    } while (0); // End cleanup block (not a loop)
-
-    do { // Begin cleanup block (not a loop)
-        QList<QNetworkProxy> netProxies =
-        QNetworkProxyFactory::systemProxyForQuery (
-        QNetworkProxyQuery(QUrl("https://www.google.com")));
-        https = netProxies[0];
-        if (QNetworkProxy::NoProxy != https.type ()) {
-            qDebug () << "Got proxy: host = " << https.hostName ()
-                      << ", port = " << https.port ();
-            break;
-        }
-
-        // Otherwise Confirm it
-#if defined(Q_WS_X11)
-        QString strHttpProxy = getenv ("https_proxy");
-        if (strHttpProxy.isEmpty ()) {
-            break;
-        }
-
-        int colon = strHttpProxy.lastIndexOf (':');
-        if (-1 != colon) {
-            QString strHost = strHttpProxy.mid (0, colon);
-            QString strPort = strHttpProxy.mid (colon);
-
-            strHost.remove ("http://").remove ("https://");
-
-            strPort.remove (':').remove ('/');
-            int port = strPort.toInt ();
-
-            qDebug () << "Found http proxy: " << strHost << ":" << port;
-            https.setHostName (strHost);
-            https.setPort (port);
-            https.setType (QNetworkProxy::HttpProxy);
-        }
-#endif
-    } while (0); // End cleanup block (not a loop)
-
-    return (true);
-}//GVWebPage::getSystemProxies
