@@ -22,19 +22,19 @@ public:
                          int            role = Qt::DisplayRole) const;
 
 public:
-    static QString type_to_string (GVH_Event_Type Type);
-    static GVH_Event_Type string_to_type (const QString &strType);
+    static QString type_to_string (GVI_Entry_Type Type);
+    static GVI_Entry_Type string_to_type (const QString &strType);
 
     bool refresh (const QString &strSelected);
     bool refresh ();
 
-    bool insertHistory (const GVHistoryEvent &hEvent);
+    bool insertEntry (const GVInboxEntry &hEvent);
 
 private:
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
 
     QString strSelectType;
-    GVH_Event_Type eSelectType;
+    GVI_Entry_Type eSelectType;
 };
 
 #endif //__INBOXMODEL_H__
