@@ -41,11 +41,6 @@ MainWindow::MainWindow (QWidget *parent)
 , bCallInProgress (false)
 , bDialCancelled (false)
 {
-#ifdef Q_WS_MAEMO_5
-    QObject::connect(QApplication::desktop(), SIGNAL(resized(int)),
-                     this                   , SLOT  (orientationChanged()));
-#endif
-
     initLogging ();
 
     OsDependent &osd = Singletons::getRef().getOSD ();
@@ -226,6 +221,17 @@ MainWindow::init ()
     // the database.
     dbMain.init ();
 
+    // Pick up proxy settings from the DB and apply to webpage.
+    bool bProxyEnable = false, bUseSystemProxy = false;
+    bool bProxyAuthRequired = false;
+    QString strProxyHost, strProxyUser, strProxyPass;
+    int proxy_port = 0;
+    dbMain.getProxySettings (bProxyEnable, bUseSystemProxy,
+                             strProxyHost, proxy_port,
+                             bProxyAuthRequired, strProxyUser, strProxyPass);
+    onSigProxyChanges (bProxyEnable, bUseSystemProxy, strProxyHost, proxy_port,
+                       bProxyAuthRequired, strProxyUser, strProxyPass);
+
     // Initialize the DBUS interface to allow other applications (and qgv-tp) to
     // initiate calls and send texts through us.
     osd.initDialServer (this, SLOT (dialNow (const QString &)));
@@ -371,6 +377,11 @@ MainWindow::initQML ()
                       this, SLOT   (close ()));
     QObject::connect (gObj, SIGNAL (sigQuit ()),
                       this, SLOT   (on_actionE_xit_triggered ()));
+    QObject::connect (
+        gObj, SIGNAL (sigProxyChanges(bool, bool, const QString &, int,
+                                      bool, const QString &, const QString &)),
+        this, SLOT (onSigProxyChanges(bool, bool, const QString &, int,
+                                      bool, const QString &, const QString &)));
 }//MainWindow::initQML
 
 void
@@ -526,21 +537,6 @@ MainWindow::loginCompleted (bool bOk, const QVariantList &varList)
     }
 }//MainWindow::loginCompleted
 
-void
-MainWindow::orientationChanged ()
-{
-    QDesktopWidget *dWgt = QApplication::desktop();
-    bool bLandscape = false;
-
-    if (NULL != dWgt) {
-        QRect screenGeometry = dWgt->screenGeometry();
-        bLandscape = (screenGeometry.width() > screenGeometry.height());
-    }
-#ifndef Q_WS_MAEMO_5
-    bLandscape = false;
-#endif
-}//MainWindow::orientationChanged
-
 void
 MainWindow::doLogout ()
 {
@@ -669,7 +665,7 @@ MainWindow::initInbox ()
 
     oInbox.loginSuccess ();
     oInbox.initModel (this);
-    oInbox.refreshHistory ();
+    oInbox.refresh ();
 }//MainWindow::initInbox
 
 void
@@ -1523,7 +1519,7 @@ MainWindow::onRefresh ()
     qDebug ("Refresh all requested.");
 
     refreshRegisteredNumbers ();
-    oInbox.refreshHistory ();
+    oInbox.refresh ();
     oContacts.refreshContacts ();
 }//MainWindow::onRefresh
 
@@ -1536,3 +1532,45 @@ MainWindow::onRefreshAll ()
     oInbox.refreshFullInbox ();
     oContacts.refreshAllContacts ();
 }//MainWindow::onRefreshAll
+
+void
+MainWindow::onSigProxyChanges(bool bEnable,
+                              bool bUseSystemProxy,
+                              const QString &host, int port,
+                              bool bRequiresAuth,
+                              const QString &user, const QString &pass)
+{
+    // Send to WebPage.
+    GVAccess &webPage = Singletons::getRef().getGVAccess ();
+    webPage.setProxySettings (bEnable, bUseSystemProxy, host, port,
+                              bRequiresAuth, user, pass);
+
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    dbMain.setProxySettings (bEnable, bUseSystemProxy, host, port,
+                             bRequiresAuth, user, pass);
+
+    do // Begin cleanup block (not a loop)
+    {
+    	QObject *pRoot = this->rootObject ();
+        if (NULL == pRoot) {
+            qWarning ("Could not get to root object in QML!!!");
+            break;
+        }
+
+        QObject *pProxySettings = pRoot->findChild <QObject*>
+                                                  ("ProxySettingsPage");
+        if (NULL == pProxySettings) {
+            qWarning ("Could not get to ProxySettingsPage");
+            break;
+        }
+        
+        QMetaObject::invokeMethod (pProxySettings, "setValues",
+                                   Q_ARG (QVariant, QVariant(bEnable)),
+                                   Q_ARG (QVariant, QVariant(bUseSystemProxy)),
+                                   Q_ARG (QVariant, QVariant(host)),
+                                   Q_ARG (QVariant, QVariant(port)),
+                                   Q_ARG (QVariant, QVariant(bRequiresAuth)),
+                                   Q_ARG (QVariant, QVariant(user)),
+                                   Q_ARG (QVariant, QVariant(pass)));
+    } while (0); // End cleanup block (not a loop)
+}//MainWindow::onSigProxyChanges
